@@ -1,9 +1,16 @@
 """Provide Event base classes for Z-Wave JS."""
-import logging
-from dataclasses import dataclass, field
-from typing import Callable, Dict, List, Literal
 
-from pydantic import BaseModel
+from __future__ import annotations
+
+from collections.abc import Callable
+from dataclasses import dataclass, field
+import logging
+from typing import Literal
+
+try:
+    from pydantic.v1 import BaseModel
+except ImportError:
+    from pydantic import BaseModel
 
 LOGGER = logging.getLogger(__package__)
 
@@ -14,6 +21,14 @@ class BaseEventModel(BaseModel):
     source: Literal["controller", "driver", "node"]
     event: str
 
+    @classmethod
+    def from_dict(cls, data: dict) -> BaseEventModel:
+        """Initialize from dict."""
+        return cls(
+            source=data["source"],
+            event=data["event"],
+        )
+
 
 @dataclass
 class Event:
@@ -28,11 +43,9 @@ class EventBase:
 
     def __init__(self) -> None:
         """Initialize event base."""
-        self._listeners: Dict[str, List[Callable]] = {}
+        self._listeners: dict[str, list[Callable]] = {}
 
-    def on(  # pylint: disable=invalid-name
-        self, event_name: str, callback: Callable
-    ) -> Callable:
+    def on(self, event_name: str, callback: Callable) -> Callable:
         """Register an event callback."""
         listeners: list = self._listeners.setdefault(event_name, [])
         listeners.append(callback)
@@ -58,7 +71,10 @@ class EventBase:
     def emit(self, event_name: str, data: dict) -> None:
         """Run all callbacks for an event."""
         for listener in self._listeners.get(event_name, []).copy():
-            listener(data)
+            try:
+                listener(data)
+            except Exception:  # pylint: disable=broad-exception-caught
+                LOGGER.exception("Error handling event: %s", event_name)
 
     def _handle_event_protocol(self, event: Event) -> None:
         """Process an event based on event protocol."""
@@ -66,4 +82,4 @@ class EventBase:
         if handler is None:
             LOGGER.debug("Received unknown event: %s", event)
             return
-        handler(event)
+        handler(event)  # pylint: disable=not-callable
